@@ -108,11 +108,6 @@ public class OXContextRestoreException extends Exception {
          */
         NO_USER_DATA_DB_FOUND("None of the files contained a userdata database dump, but this is essential for the restore process"),
 
-        /**
-         * One of the given filenames cannot be found
-         */
-        FILE_NOT_FOUND("One of the given filenames cannot be found"),
-
         /**
          * An IO Exception has occurred, see the log files for details
          */
@@ -138,6 +133,21 @@ public class OXContextRestoreException extends Exception {
          */
         NO_ENTRIES_IN_UPDATE_TASK_TABLE("No entries in updateTask table"),
 
+        /**
+         * An unexpected error occurred: %s
+         */
+        UNEXPECTED_ERROR("An unexpected error occurred: %s"),
+
+        /**
+         * One of the given filenames cannot be found
+         */
+        USERDB_FILE_NOT_FOUND("Temp file for user database values cannot be found"),
+
+        /**
+         * One of the given filenames cannot be found
+         */
+        CONFIGDB_FILE_NOT_FOUND("Temp file for confidb values cannot be found"),
+        
         ;
 
         private final String text;
