@@ -67,7 +67,6 @@ import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.apache.commons.io.output.NullWriter;
-import org.apache.commons.logging.Log;
 import com.openexchange.admin.contextrestore.dataobjects.UpdateTaskEntry;
 import com.openexchange.admin.contextrestore.dataobjects.UpdateTaskInformation;
 import com.openexchange.admin.contextrestore.dataobjects.VersionInformation;
@@ -88,7 +87,6 @@ import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.rmi.impl.BasicAuthenticator;
 import com.openexchange.admin.rmi.impl.OXCommonImpl;
 import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
-import com.openexchange.log.LogFactory;
 
 /**
  * This class contains the implementation of the API defined in {@link OXContextRestoreInterface}
@@ -101,9 +99,9 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
     public class RunParserResult {
 
         private final PoolIdSchemaAndVersionInfo result;
-        
+
         private final UpdateTaskInformation updateTaskInfo;
-        
+
         private final VersionInformation versionInfo;
 
         public RunParserResult(PoolIdSchemaAndVersionInfo result, UpdateTaskInformation updateTaskInfo, VersionInformation versionInfo) {
@@ -120,11 +118,11 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
         public UpdateTaskInformation getUpdateTaskInfo() {
             return updateTaskInfo;
         }
-        
+
         public VersionInformation getVersionInfo() {
             return versionInfo;
         }
-        
+
     }
 
     /** The reference for ConfigDB name */
@@ -180,7 +178,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
             private final int contextId;
             private final String schema;
             private final String fileName;
-            
+
             private Map<String, File> tempfilemap;
             private VersionInformation versionInformation;
             private UpdateTaskInformation updateTaskInformation;
@@ -307,7 +305,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                                 final String databasename = dbmatcher.group(1);
                                 if (getConfigDbName(optConfigDbName).equals(databasename) || (null != schema && schema.equals(databasename))) {
                                     furthersearch = true;
-                                    LOG.info("Database: " + databasename);
+                                    LOG.info("Database: {}", databasename);
                                     if (null != bufferedWriter) {
                                         bufferedWriter.append("/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;\n");
                                         bufferedWriter.flush();
@@ -333,7 +331,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                             } else if (furthersearch && tablematcher.matches()) {
                                 // Table found
                                 tableName = tablematcher.group(1);
-                                LOG.info("Table: " + tableName);
+                                LOG.info("Table: {}", tableName);
                                 cidpos = -1;
                                 oldstate = 0;
                                 state = 3;
@@ -376,7 +374,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                         continue;
                     } else if (4 == state && c == '(') {
                         cidpos = cidsearch(in);
-                        LOG.info("Cid pos: " + cidpos);
+                        LOG.info("Cid pos: {}", cidpos);
                         state = 0;
                         continue;
                     } else if (5 == state && c == 'I') {
@@ -386,7 +384,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                         oldstate = 5;
                         state = 1;
                     } else if (6 == state && c == '(') {
-                        LOG.info("Insert found and cid=" + cidpos);
+                        LOG.info("Insert found and cid={}", cidpos);
                         // Now we search for matching cids and write them to the tmp file
                         if (searchcontext && null != bufferedWriter) {
                             final String value[] =
@@ -659,7 +657,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                 // Now searching for cid text...
                 if (cidmatcher.matches()) {
                     final List<String> searchingForeignKey = searchingForeignKey(in);
-                    LOG.info("Foreign Keys: " + searchingForeignKey);
+                    LOG.info("Foreign Keys: {}", searchingForeignKey);
                     found = true;
                     break;
                 } else if (enginematcher.matches()) {
@@ -705,7 +703,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
 
     }
 
-    protected final static Log LOG = LogFactory.getLog(OXContextRestore.class);
+    protected final static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(OXContextRestore.class);
 
     private final BasicAuthenticator basicauth;
 
@@ -729,12 +727,12 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
         try {
             basicauth.doAuthentication(auth);
         } catch (final InvalidCredentialsException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         }
 
-        LOG.info("Context: " + ctx);
-        LOG.info("Filenames: " + java.util.Arrays.toString(fileNames));
+        LOG.info("Context: {}", ctx);
+        LOG.info("Filenames: {}", java.util.Arrays.toString(fileNames));
 
         try {
             final HashMap<String, File> tempfilemap = new HashMap<String, File>();
@@ -771,27 +769,27 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                     contextInterface.delete(ctx, auth);
                 } catch (final NoSuchContextException e) {
                     // As we check for the existence beforehand this exception should never occur. Nevertheless we will log this
-                    LOG.fatal("FATAL:" + e.getMessage(), e);
+                    LOG.error("FATAL", e);
                 }
             }
             return instance.restorectx(ctx, result, getConfigDbName(optConfigDbName));
         } catch (final StorageException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         } catch (final IOException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw new OXContextRestoreException(Code.IO_EXCEPTION, e);
         } catch (final SQLException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw new OXContextRestoreException(Code.DATABASE_OPERATION_ERROR, e, e.getMessage());
         } catch (final OXContextRestoreException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         } catch (final DatabaseUpdateException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw new OXContextRestoreException(Code.UNEXPECTED_ERROR, e, e.getMessage());
         }
     }
